@@ -293,6 +293,7 @@ static unsigned inifcns_consist_exp()
 
 static unsigned inifcns_consist_log()
 {
+	using GiNaC::log;
 	unsigned result = 0;
 	symbol z("a"), w("b");
 	realsymbol a("a"), b("b");
@@ -349,7 +350,7 @@ static unsigned inifcns_consist_various()
 	return result;
 }
 
-/* Several tests for derivetives */
+/* Several tests for derivatives */
 static unsigned inifcns_consist_derivatives()
 {
 	unsigned result = 0;
