@@ -6,7 +6,7 @@
  */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2015 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,13 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include "times.h"
+#include "ginac.h"
+#include "timer.h"
+using namespace GiNaC;
+
+#include <iostream>
+#include <vector>
+using namespace std;
 
 static unsigned toeplitz_det(unsigned size)
 {
@@ -69,7 +75,6 @@ unsigned time_toeplitz()
 	unsigned result = 0;
 
 	cout << "timing determinant of polyvariate symbolic Toeplitz matrices" << flush;
-	clog << "-------determinant of polyvariate symbolic Toeplitz matrices:" << endl;
 
 	vector<unsigned> sizes;
 	vector<double> times;
@@ -93,12 +98,6 @@ unsigned time_toeplitz()
 		cout << '.' << flush;
 	}
 
-	if (!result) {
-		cout << " passed ";
-		clog << "(no output)" << endl;
-	} else {
-		cout << " failed ";
-	}
 	// print the report:
 	cout << endl << "	dim:   ";
 	for (vector<unsigned>::iterator i=sizes.begin(); i!=sizes.end(); ++i)
@@ -110,3 +109,12 @@ unsigned time_toeplitz()
 
 	return result;
 }
+
+extern void randomify_symbol_serials();
+
+int main(int argc, char** argv)
+{
+	randomify_symbol_serials();
+	cout << setprecision(2) << showpoint;
+	return time_toeplitz();
+}
