@@ -32,6 +32,7 @@
 #include "utils.h"
 #include "hash_seed.h"
 #include "indexed.h"
+#include "compiler.h"
 
 #include <algorithm>
 #if EXPAIRSEQ_USE_HASHTAB
@@ -661,7 +662,7 @@ ex expairseq::expand(unsigned options) const
  *  has (at least) two possible different semantics but we want to inherit
  *  methods thus avoiding code duplication.  Sometimes a method in expairseq
  *  has to create a new one of the same semantics, which cannot be done by a
- *  ctor because the name (add, mul,...) is unknown on the expaiseq level.  In
+ *  ctor because the name (add, mul,...) is unknown on the expairseq level.  In
  *  order for this trick to work a derived class must of course override this
  *  definition. */
 ex expairseq::thisexpairseq(const epvector &v, const ex &oc, bool do_index_renaming) const
@@ -1524,7 +1525,7 @@ bool expairseq::is_canonical() const
 		return 1;
 	
 #if EXPAIRSEQ_USE_HASHTAB
-	if (hashtabsize > 0) return 1; // not canoncalized
+	if (hashtabsize > 0) return 1; // not canonicalized
 #endif // EXPAIRSEQ_USE_HASHTAB
 	
 	epvector::const_iterator it = seq.begin(), itend = seq.end();
@@ -1610,7 +1611,7 @@ std::auto_ptr<epvector> expairseq::evalchildren(int level) const
 	// returns a pointer to a newly created epvector otherwise
 	// (which has to be deleted somewhere else)
 
-	if (level==1)
+	if (likely(level==1))
 		return std::auto_ptr<epvector>(0);
 	
 	if (level == -max_recursion_level)
