@@ -3,7 +3,7 @@
  *  Interface to the parser. */
 
 /*
- *  GiNaC Copyright (C) 1999-2011 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2015 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -67,6 +67,9 @@ class parser
 	/// paren_expr: '(' expression ')'
 	ex parse_paren_expr();
 
+	/// lst_expr: '{' expression { ',' expression } '}'
+	ex parse_lst_expr();
+
 	/// number_expr: number
 	ex parse_number_expr();
 
