@@ -3,7 +3,7 @@
  *  Implementation of GiNaC's symmetry definitions. */
 
 /*
- *  GiNaC Copyright (C) 1999-2010 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2015 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 
 #include "symmetry.h"
 #include "lst.h"
+#include "add.h"
 #include "numeric.h" // for factorial()
 #include "operators.h"
 #include "archive.h"
@@ -160,7 +161,7 @@ int symmetry::compare_same_type(const basic & other) const
 		return 1;
 	if (this_size < that_size)
 		return -1;
-	typedef std::set<unsigned>::iterator set_it;
+	typedef std::set<unsigned>::const_iterator set_it;
 	set_it end = indices.end();
 	for (set_it i=indices.begin(),j=othersymm.indices.begin(); i!=end; ++i,++j) {
 		if(*i < *j)
@@ -269,6 +270,18 @@ void symmetry::do_print_tree(const print_tree & c, unsigned level) const
 // non-virtual functions in this class
 //////////
 
+bool symmetry::has_nonsymmetric() const
+{
+	if (type == antisymmetric || type == cyclic)
+		return true;
+
+	for (exvector::const_iterator i=children.begin(); i!=children.end(); ++i)
+		if (ex_to<symmetry>(*i).has_nonsymmetric())
+			return true;
+
+	return false;
+}
+
 bool symmetry::has_cyclic() const
 {
 	if (type == cyclic)
@@ -495,7 +508,8 @@ static ex symm(const ex & e, exvector::const_iterator first, exvector::const_ite
 
 	// Loop over all permutations (the first permutation, which is the
 	// identity, is unrolled)
-	ex sum = e;
+	exvector sum_v;
+	sum_v.push_back(e);
 	while (std::next_permutation(iv, iv + num)) {
 		lst new_lst;
 		for (unsigned i=0; i<num; i++)
@@ -505,8 +519,9 @@ static ex symm(const ex & e, exvector::const_iterator first, exvector::const_ite
 			memcpy(iv2, iv, num * sizeof(unsigned));
 			term *= permutation_sign(iv2, iv2 + num);
 		}
-		sum += term;
+		sum_v.push_back(term);
 	}
+	ex sum = (new add(sum_v))->setflag(status_flags::dynallocated);
 
 	delete[] iv;
 	delete[] iv2;
