@@ -3,7 +3,7 @@
  *  Interface to GiNaC's wildcard objects. */
 
 /*
- *  GiNaC Copyright (C) 1999-2007 Johannes Gutenberg University Mainz, Germany
+ *  GiNaC Copyright (C) 1999-2015 Johannes Gutenberg University Mainz, Germany
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,14 +20,14 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GINAC_WILDCARD_H__
-#define __GINAC_WILDCARD_H__
+#ifndef GINAC_WILDCARD_H
+#define GINAC_WILDCARD_H
 
 #include "ex.h"
+#include "archive.h"
 
 namespace GiNaC {
 
-
 /** This class acts as a wildcard for subs(), match(), has() and find(). An
  *  integer label is used to identify different wildcards. */
 class wildcard : public basic
@@ -41,8 +41,12 @@ public:
 
 	// functions overriding virtual functions from base classes
 public:
-	bool match(const ex & pattern, lst & repl_lst) const;
+	bool match(const ex & pattern, exmap& repl_lst) const;
 
+	/** Save (a.k.a. serialize) object into archive. */
+	void archive(archive_node& n) const;
+	/** Read (a.k.a. deserialize) object from archive. */
+	void read_archive(const archive_node& n, lst& syms);
 protected:
 	unsigned calchash() const;
 
@@ -59,6 +63,7 @@ protected:
 private:
 	unsigned label; /**< Label used to distinguish different wildcards */
 };
+GINAC_DECLARE_UNARCHIVER(wildcard);
 
 
 // utility functions
@@ -74,4 +79,4 @@ bool haswild(const ex & x);
 
 } // namespace GiNaC
 
-#endif // ndef __GINAC_WILDCARD_H__
+#endif // ndef GINAC_WILDCARD_H
